@@ -50,7 +50,7 @@ import (
 
 	orgv1 "github.com/eclipse-che/che-operator/api/v1"
 	userv1 "github.com/openshift/api/user/v1"
-	"k8s.io/api/extensions/v1beta1"
+	networking "k8s.io/api/networking/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 )
 
@@ -94,10 +94,12 @@ type CheClusterReconciler struct {
 	tests             bool
 	userHandler       OpenShiftOAuthUserHandler
 	permissionChecker PermissionChecker
+	// the namespace to which to limit the reconciliation. If empty, all namespaces are considered
+	namespace string
 }
 
 // NewReconciler returns a new CheClusterReconciler
-func NewReconciler(mgr ctrl.Manager) (*CheClusterReconciler, error) {
+func NewReconciler(mgr ctrl.Manager, namespace string) (*CheClusterReconciler, error) {
 	noncachedClient, err := client.New(mgr.GetConfig(), client.Options{Scheme: mgr.GetScheme()})
 	if err != nil {
 		return nil, err
@@ -115,6 +117,7 @@ func NewReconciler(mgr ctrl.Manager) (*CheClusterReconciler, error) {
 		discoveryClient:   discoveryClient,
 		userHandler:       NewOpenShiftOAuthUserHandler(noncachedClient),
 		permissionChecker: &K8sApiPermissionChecker{},
+		namespace:         namespace,
 	}, nil
 }
 
@@ -208,12 +211,16 @@ func (r *CheClusterReconciler) SetupWithManager(mgr ctrl.Manager) error {
 			OwnerType:    &orgv1.CheCluster{},
 		})
 	} else {
-		contollerBuilder = contollerBuilder.Watches(&source.Kind{Type: &v1beta1.Ingress{}}, &handler.EnqueueRequestForOwner{
+		contollerBuilder = contollerBuilder.Watches(&source.Kind{Type: &networking.Ingress{}}, &handler.EnqueueRequestForOwner{
 			IsController: true,
 			OwnerType:    &orgv1.CheCluster{},
 		})
 	}
 
+	if r.namespace != "" {
+		contollerBuilder.WithEventFilter(util.InNamespaceEventFilter(r.namespace))
+	}
+
 	return contollerBuilder.
 		For(&orgv1.CheCluster{}).
 		Complete(r)
@@ -315,6 +322,14 @@ func (r *CheClusterReconciler) Reconcile(req ctrl.Request) (ctrl.Result, error)
 		}
 	}
 
+	if util.IsOpenShift && instance.Spec.DevWorkspace.Enable && instance.Spec.Auth.NativeUserMode == nil {
+		newNativeUserModeValue := util.NewBoolPointer(true)
+		instance.Spec.Auth.NativeUserMode = newNativeUserModeValue
+		if err := deploy.UpdateCheCRSpec(deployContext, "nativeUserMode", strconv.FormatBool(*newNativeUserModeValue)); err != nil {
+			return reconcile.Result{Requeue: true, RequeueAfter: time.Second * 1}, err
+		}
+	}
+
 	if util.IsOpenShift && instance.Spec.Auth.OpenShiftoAuth == nil {
 		if reconcileResult, err := r.autoEnableOAuth(deployContext, req, util.IsOpenShift4); err != nil {
 			return reconcileResult, err
@@ -528,6 +543,17 @@ func (r *CheClusterReconciler) Reconcile(req ctrl.Request) (ctrl.Result, error)
 		}
 	}
 
+	devfileRegistry := devfileregistry.NewDevfileRegistry(deployContext)
+	if !instance.Spec.Server.ExternalDevfileRegistry {
+		done, err := devfileRegistry.SyncAll()
+		if !done {
+			if err != nil {
+				logrus.Error(err)
+			}
+			return ctrl.Result{}, err
+		}
+	}
+
 	if !instance.Spec.Server.ExternalPluginRegistry {
 		pluginRegistry := pluginregistry.NewPluginRegistry(deployContext)
 		done, err := pluginRegistry.SyncAll()
@@ -546,19 +572,8 @@ func (r *CheClusterReconciler) Reconcile(req ctrl.Request) (ctrl.Result, error)
 		}
 	}
 
-	devfileRegistry := devfileregistry.NewDevfileRegistry(deployContext)
-	if !instance.Spec.Server.ExternalDevfileRegistry {
-		done, err := devfileRegistry.SyncAll()
-		if !done {
-			if err != nil {
-				logrus.Error(err)
-			}
-			return ctrl.Result{}, err
-		}
-	}
-
 	d := dashboard.NewDashboard(deployContext)
-	done, err = d.SyncAll()
+	done, err = d.Reconcile()
 	if !done {
 		if err != nil {
 			logrus.Errorf("Error provisioning '%s' to cluster: %v", d.GetComponentName(), err)
@@ -783,6 +798,13 @@ func (r *CheClusterReconciler) reconcileFinalizers(deployContext *deploy.DeployC
 		logrus.Error(err)
 	}
 
+	if !deployContext.CheCluster.ObjectMeta.DeletionTimestamp.IsZero() {
+		done, err := dashboard.NewDashboard(deployContext).Finalize()
+		if !done {
+			logrus.Error(err)
+		}
+	}
+
 	if len(deployContext.CheCluster.Spec.Server.CheClusterRoles) > 0 {
 		cheClusterRoles := strings.Split(deployContext.CheCluster.Spec.Server.CheClusterRoles, ",")
 		for _, cheClusterRole := range cheClusterRoles {
