@@ -53,6 +53,10 @@ func SyncDeploymentSpecToCluster(
 		return false, err
 	}
 
+	if err := MountConfigMaps(deploymentSpec, deployContext); err != nil {
+		return false, err
+	}
+
 	done, err := Sync(deployContext, deploymentSpec, deploymentDiffOpts)
 	if err != nil || !done {
 		return false, err
@@ -176,3 +180,103 @@ func MountSecrets(specDeployment *appsv1.Deployment, deployContext *DeployContex
 
 	return nil
 }
+
+// MountConfigMaps mounts configmaps into a container as a file or as environment variable.
+// Configmaps are selected by the following labels:
+// - app.kubernetes.io/part-of=che.eclipse.org
+// - app.kubernetes.io/component=<DEPLOYMENT-NAME>-configmap
+func MountConfigMaps(specDeployment *appsv1.Deployment, deployContext *DeployContext) error {
+	configmaps := &corev1.ConfigMapList{}
+
+	kubernetesPartOfLabelSelectorRequirement, _ := labels.NewRequirement(KubernetesPartOfLabelKey, selection.Equals, []string{CheEclipseOrg})
+	kubernetesComponentLabelSelectorRequirement, _ := labels.NewRequirement(KubernetesComponentLabelKey, selection.Equals, []string{specDeployment.Name + "-configmap"})
+
+	listOptions := &client.ListOptions{
+		LabelSelector: labels.NewSelector().Add(*kubernetesPartOfLabelSelectorRequirement).Add(*kubernetesComponentLabelSelectorRequirement),
+	}
+	if err := deployContext.ClusterAPI.Client.List(context.TODO(), configmaps, listOptions); err != nil {
+		return err
+	}
+
+	// sort configmaps by name first to have the same order every time
+	sort.Slice(configmaps.Items, func(i, j int) bool {
+		return strings.Compare(configmaps.Items[i].Name, configmaps.Items[j].Name) < 0
+	})
+
+	container := &specDeployment.Spec.Template.Spec.Containers[0]
+	for _, configMapObj := range configmaps.Items {
+		switch configMapObj.Annotations[CheEclipseOrgMountAs] {
+		case "file":
+			voluseSource := corev1.VolumeSource{
+				ConfigMap: &corev1.ConfigMapVolumeSource{
+					LocalObjectReference: corev1.LocalObjectReference{
+						Name: configMapObj.Name,
+					},
+				},
+			}
+
+			volume := corev1.Volume{
+				Name:         configMapObj.Name,
+				VolumeSource: voluseSource,
+			}
+
+			volumeMount := corev1.VolumeMount{
+				Name:      configMapObj.Name,
+				MountPath: configMapObj.Annotations[CheEclipseOrgMountPath],
+			}
+
+			specDeployment.Spec.Template.Spec.Volumes = append(specDeployment.Spec.Template.Spec.Volumes, volume)
+			container.VolumeMounts = append(container.VolumeMounts, volumeMount)
+
+		case "env":
+			configmap := &corev1.ConfigMap{}
+			exists, err := GetNamespacedObject(deployContext, configMapObj.Name, configmap)
+			if err != nil {
+				return err
+			} else if !exists {
+				return fmt.Errorf("ConfigMap '%s' not found", configMapObj.Name)
+			}
+
+			// grab all keys and sort first to have the same order every time
+			keys := make([]string, 0)
+			for k := range configmap.Data {
+				keys = append(keys, k)
+			}
+			sort.Slice(keys, func(i, j int) bool {
+				return strings.Compare(keys[i], keys[j]) < 0
+			})
+
+			for _, key := range keys {
+				var envName string
+
+				// check if evn name defined explicitly
+				envNameAnnotation := CheEclipseOrg + "/" + key + "_env-name"
+				envName, envNameExists := configMapObj.Annotations[envNameAnnotation]
+				if !envNameExists {
+					// check if there is only one env name to mount
+					envName, envNameExists = configMapObj.Annotations[CheEclipseOrgEnvName]
+					if len(configmap.Data) > 1 {
+						return fmt.Errorf("There are more than one environment variable to mount. Use annotation '%s' to specify a name", envNameAnnotation)
+					} else if !envNameExists {
+						return fmt.Errorf("Environment name to mount configmap key not found. Use annotation '%s' to specify a name", CheEclipseOrgEnvName)
+					}
+				}
+
+				env := corev1.EnvVar{
+					Name: envName,
+					ValueFrom: &corev1.EnvVarSource{
+						ConfigMapKeyRef: &corev1.ConfigMapKeySelector{
+							Key: key,
+							LocalObjectReference: corev1.LocalObjectReference{
+								Name: configMapObj.Name,
+							},
+						},
+					},
+				}
+				container.Env = append(container.Env, env)
+			}
+		}
+	}
+
+	return nil
+}
