@@ -17,6 +17,7 @@ import (
 	"errors"
 	"fmt"
 	"io/ioutil"
+	"os"
 	"strings"
 
 	orgv1 "github.com/eclipse-che/che-operator/api/v1"
@@ -46,9 +47,8 @@ var (
 	DevWorkspaceDeploymentName = "devworkspace-controller-manager"
 
 	SubscriptionResourceName          = "subscriptions"
-	CheManagerResourcename            = "chemanagers"
 	ClusterServiceVersionResourceName = "clusterserviceversions"
-	DevWorkspaceCSVNameWithouVersion  = "devworkspace-operator"
+	DevWorkspaceCSVNamePrefix         = "devworkspace-operator"
 
 	OpenshiftDevWorkspaceTemplatesPath  = "/tmp/devworkspace-operator/templates/deployment/openshift/objects"
 	KubernetesDevWorkspaceTemplatesPath = "/tmp/devworkspace-operator/templates/deployment/kubernetes/objects"
@@ -105,6 +105,13 @@ var (
 		syncDwConfigMap,
 		syncDwDeployment,
 	}
+
+	// Exits the operator after successful fresh installation of the devworkspace.
+	// Can be replaced with something less drastic (especially useful in tests)
+	afterInstall = func() {
+		logrus.Warn("Exitting the operator after DevWorkspace installation. DevWorkspace support will be initialized on the next start.")
+		os.Exit(1)
+	}
 )
 
 func ReconcileDevWorkspace(deployContext *deploy.DeployContext) (bool, error) {
@@ -113,17 +120,29 @@ func ReconcileDevWorkspace(deployContext *deploy.DeployContext) (bool, error) {
 		return true, nil
 	}
 
-	// Check if exists devworkspace operator csv is already installed
-	devWorkspaceOperatorCSVExists := isDevWorkspaceOperatorCSVExists(deployContext)
-	if devWorkspaceOperatorCSVExists {
+	if !deployContext.CheCluster.Spec.DevWorkspace.Enable {
+		// Do nothing if Devworkspace is disabled
 		return true, nil
 	}
 
-	// do nothing if dev workspace is disabled
-	if !deployContext.CheCluster.Spec.DevWorkspace.Enable {
+	if isDevWorkspaceOperatorCSVExists(deployContext) {
+		// Do nothing if Devworkspace has been already deployed via OLM
 		return true, nil
 	}
 
+	if !deploy.IsDevWorkspaceEngineAllowed() {
+		// Note: When the tech-preview-stable-all-namespaces will be by default stable-all-namespaces 7.40.0?, change the channel from the log
+
+		if exists, _ := isDevWorkspaceDeploymentExists(deployContext); !exists {
+			// Don't allow to deploy a new Devworkspace operator
+			return false, fmt.Errorf("To enable DevWorkspace engine, deploy CodeReady Workspaces from tech-preview channel.")
+		}
+
+		// Allow existed CodeReady Workspaces and Devworkspace deployments to work
+		// event though is not allowed (for backward compatibility)
+		logrus.Warnf("To enable DevWorkspace engine, deploy CodeReady Workspaces from tech-preview channel.")
+	}
+
 	if !util.IsOpenShift && util.GetCheServerCustomCheProperty(deployContext.CheCluster, "CHE_INFRA_KUBERNETES_ENABLE__UNSUPPORTED__K8S") != "true" {
 		logrus.Warn(`DevWorkspace Che operator can't be enabled on a Kubernetes cluster without explicitly enabled k8s API on che-server. To enable DevWorkspace Che operator set 'spec.server.customCheProperties[CHE_INFRA_KUBERNETES_ENABLE__UNSUPPORTED__K8S]' to 'true'.`)
 		return true, nil
@@ -147,17 +166,31 @@ func ReconcileDevWorkspace(deployContext *deploy.DeployContext) (bool, error) {
 	}
 
 	for _, syncItem := range syncItems {
-		done, err := syncItem(deployContext)
+		_, err := syncItem(deployContext)
 		if !util.IsTestMode() {
-			if !done {
+			if err != nil {
 				return false, err
 			}
 		}
 	}
 
+	if !devWorkspaceWebhookExists && !util.IsTestMode() {
+		// the webhook did not exist in the cluster
+		// this means that we're installing devworkspace and therefore need to restart
+		// so that devworkspace support can initialize during the operator startup
+		afterInstall()
+	}
+
 	return true, nil
 }
 
+func isDevWorkspaceDeploymentExists(deployContext *deploy.DeployContext) (bool, error) {
+	return deploy.Get(deployContext, types.NamespacedName{
+		Namespace: DevWorkspaceNamespace,
+		Name:      DevWorkspaceDeploymentName,
+	}, &appsv1.Deployment{})
+}
+
 func isDevWorkspaceOperatorCSVExists(deployContext *deploy.DeployContext) bool {
 	// If clusterserviceversions resource doesn't exist in cluster DWO as well will not be present
 	if !util.HasK8SResourceObject(deployContext.ClusterAPI.DiscoveryClient, ClusterServiceVersionResourceName) {
@@ -171,7 +204,7 @@ func isDevWorkspaceOperatorCSVExists(deployContext *deploy.DeployContext) bool {
 	}
 
 	for _, csv := range csvList.Items {
-		if strings.Contains(csv.Name, DevWorkspaceCSVNameWithouVersion) {
+		if strings.HasPrefix(csv.Name, DevWorkspaceCSVNamePrefix) {
 			return true
 		}
 	}
@@ -200,7 +233,7 @@ func checkWebTerminalSubscription(deployContext *deploy.DeployContext) error {
 		return err
 	}
 
-	return errors.New("A non matching version of the Dev Workspace operator is already installed")
+	return errors.New("a non matching version of the Dev Workspace operator is already installed")
 }
 
 func createDwNamespace(deployContext *deploy.DeployContext) (bool, error) {
