@@ -13,19 +13,23 @@ package devworkspace
 
 import (
 	"context"
+	"os"
+	"strings"
+
+	"testing"
 
 	orgv1 "github.com/eclipse-che/che-operator/api/v1"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 	"github.com/eclipse-che/che-operator/pkg/util"
 	operatorsv1alpha1 "github.com/operator-framework/api/pkg/operators/v1alpha1"
+	"github.com/stretchr/testify/assert"
 	admissionregistrationv1 "k8s.io/api/admissionregistration/v1"
+	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	fakeDiscovery "k8s.io/client-go/discovery/fake"
 	"sigs.k8s.io/controller-runtime/pkg/client"
-
-	"testing"
 )
 
 const (
@@ -116,17 +120,11 @@ func TestReconcileDevWorkspace(t *testing.T) {
 		t.Run(testCase.name, func(t *testing.T) {
 			deployContext := deploy.GetTestDeployContext(testCase.cheCluster, []runtime.Object{})
 			deployContext.ClusterAPI.Scheme.AddKnownTypes(operatorsv1alpha1.SchemeGroupVersion, &operatorsv1alpha1.Subscription{})
-			deployContext.ClusterAPI.Scheme.AddKnownTypes(operatorsv1alpha1.SchemeGroupVersion, &operatorsv1alpha1.ClusterServiceVersion{})
-			deployContext.ClusterAPI.DiscoveryClient.(*fakeDiscovery.FakeDiscovery).Fake.Resources = []*metav1.APIResourceList{
-				{
-					APIResources: []metav1.APIResource{
-						{Name: CheManagerResourcename},
-					},
-				},
-			}
 
 			util.IsOpenShift = testCase.IsOpenShift
 			util.IsOpenShift4 = testCase.IsOpenShift4
+			os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
+
 			done, err := ReconcileDevWorkspace(deployContext)
 			if err != nil {
 				t.Fatalf("Error: %v", err)
@@ -138,6 +136,68 @@ func TestReconcileDevWorkspace(t *testing.T) {
 	}
 }
 
+func TestShouldNotReconcileDevWorkspaceIfForbiden(t *testing.T) {
+	cheCluster := &orgv1.CheCluster{
+		ObjectMeta: metav1.ObjectMeta{
+			Namespace: "eclipse-che",
+			Name:      "eclipse-che",
+		},
+		Spec: orgv1.CheClusterSpec{
+			DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
+				Enable: true,
+			},
+		},
+	}
+
+	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{})
+
+	util.IsOpenShift = true
+	util.IsOpenShift4 = true
+	os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "false")
+
+	reconciled, err := ReconcileDevWorkspace(deployContext)
+
+	assert.False(t, reconciled, "Devworkspace should not be reconciled")
+	assert.NotNil(t, err, "Error expected")
+	assert.True(t, strings.Contains(err.Error(), "deploy CodeReady Workspaces from tech-preview channel"), "Unrecognized error occurred %v", err)
+}
+
+func TestShouldReconcileDevWorkspaceIfDevWorkspaceDeploymentExists(t *testing.T) {
+	cheCluster := &orgv1.CheCluster{
+		ObjectMeta: metav1.ObjectMeta{
+			Namespace: "eclipse-che",
+			Name:      "eclipse-che",
+		},
+		Spec: orgv1.CheClusterSpec{
+			DevWorkspace: orgv1.CheClusterSpecDevWorkspace{
+				Enable: true,
+			},
+		},
+	}
+
+	devworkspaceDeployment := &appsv1.Deployment{
+		TypeMeta: metav1.TypeMeta{
+			Kind:       "Deployment",
+			APIVersion: "apps/v1",
+		},
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      DevWorkspaceDeploymentName,
+			Namespace: DevWorkspaceNamespace,
+		},
+	}
+
+	deployContext := deploy.GetTestDeployContext(cheCluster, []runtime.Object{devworkspaceDeployment})
+
+	util.IsOpenShift = true
+	util.IsOpenShift4 = true
+	os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "false")
+
+	reconciled, err := ReconcileDevWorkspace(deployContext)
+
+	assert.Nil(t, err, "Reconciliation error occurred %v", err)
+	assert.True(t, reconciled, "Devworkspace should be reconciled.")
+}
+
 func TestReconcileDevWorkspaceShouldThrowErrorIfWebTerminalSubscriptionExists(t *testing.T) {
 	cheCluster := &orgv1.CheCluster{
 		ObjectMeta: metav1.ObjectMeta{
@@ -178,12 +238,12 @@ func TestReconcileDevWorkspaceShouldThrowErrorIfWebTerminalSubscriptionExists(t
 			},
 		},
 	}
-
 	util.IsOpenShift = true
 	util.IsOpenShift4 = true
+	os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
 	_, err := ReconcileDevWorkspace(deployContext)
 
-	if err == nil || err.Error() != "A non matching version of the Dev Workspace operator is already installed" {
+	if err == nil || err.Error() != "a non matching version of the Dev Workspace operator is already installed" {
 		t.Fatalf("Error should be thrown")
 	}
 }
@@ -229,6 +289,7 @@ func TestReconcileDevWorkspaceCheckIfCSVExists(t *testing.T) {
 
 	util.IsOpenShift = true
 	util.IsOpenShift4 = true
+	os.Setenv("ALLOW_DEVWORKSPACE_ENGINE", "true")
 	reconciled, _ := ReconcileDevWorkspace(deployContext)
 
 	if !reconciled {
