@@ -18,7 +18,7 @@ import (
 	"strconv"
 	"strings"
 
-	orgv1 "github.com/eclipse-che/che-operator/pkg/apis/org/v1"
+	orgv1 "github.com/eclipse-che/che-operator/api/v1"
 	"github.com/eclipse-che/che-operator/pkg/deploy"
 	"github.com/eclipse-che/che-operator/pkg/util"
 	"github.com/google/go-cmp/cmp"
@@ -517,7 +517,7 @@ func GetSpecKeycloakDeployment(
 	}
 
 	var enableFixedHostNameProvider string
-	if deployContext.CheCluster.Spec.Server.UseInternalClusterSVCNames {
+	if deployContext.CheCluster.IsInternalClusterSVCNamesEnabled() {
 		if cheFlavor == "che" {
 			keycloakURL, err := url.Parse(deployContext.CheCluster.Status.KeycloakURL)
 			if err != nil {
