@@ -22,7 +22,7 @@ import (
 	"github.com/sirupsen/logrus"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
-	"k8s.io/api/extensions/v1beta1"
+	networking "k8s.io/api/networking/v1"
 )
 
 const (
@@ -59,11 +59,6 @@ func (s *Server) ExposeCheServiceAndEndpoint() (bool, error) {
 		return false, err
 	}
 
-	done, err = s.UpdateCheURL()
-	if !done {
-		return false, err
-	}
-
 	return true, nil
 }
 
@@ -100,6 +95,11 @@ func (s *Server) SyncAll() (bool, error) {
 		return false, err
 	}
 
+	done, err = s.UpdateCheURL()
+	if !done {
+		return false, err
+	}
+
 	done, err = s.UpdateCheVersion()
 	if !done {
 		return false, err
@@ -144,7 +144,7 @@ func (s Server) ExposeCheEndpoint() (bool, error) {
 			return false, err
 		}
 
-		ingress := &v1beta1.Ingress{}
+		ingress := &networking.Ingress{}
 		exists, err := deploy.GetNamespacedObject(s.deployContext, s.component, ingress)
 		if !exists {
 			return false, err
@@ -193,13 +193,7 @@ func (s Server) ExposeCheEndpoint() (bool, error) {
 }
 
 func (s Server) UpdateCheURL() (bool, error) {
-	var cheUrl string
-	if s.deployContext.CheCluster.Spec.Server.TlsSupport {
-		cheUrl = "https://" + s.deployContext.CheCluster.Spec.Server.CheHost
-	} else {
-		cheUrl = "http://" + s.deployContext.CheCluster.Spec.Server.CheHost
-	}
-
+	var cheUrl = util.GetCheURL(s.deployContext.CheCluster)
 	if s.deployContext.CheCluster.Status.CheURL != cheUrl {
 		s.deployContext.CheCluster.Status.CheURL = cheUrl
 		err := deploy.UpdateCheCRStatus(s.deployContext, s.component+" server URL", cheUrl)
