@@ -14,7 +14,7 @@ package deploy
 import (
 	"context"
 
-	orgv1 "github.com/eclipse-che/che-operator/pkg/apis/org/v1"
+	orgv1 "github.com/eclipse-che/che-operator/api/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
@@ -53,7 +53,7 @@ func TestServiceToCluster(t *testing.T) {
 	}
 
 	actual := &corev1.Service{}
-	err = cli.Get(context.TODO(), types.NamespacedName{Name: "test"}, actual)
+	err = cli.Get(context.TODO(), types.NamespacedName{Name: "test", Namespace: "eclipse-che"}, actual)
 	if err != nil {
 		t.Fatalf("Failed to get service: %v", err)
 	}
