@@ -28,7 +28,7 @@ import (
 
 // Sync syncs the blueprint to the cluster in a generic (as much as Go allows) manner.
 // Returns true if object is up to date otherwiser returns false
-func Sync(deployContext *DeployContext, blueprint metav1.Object, diffOpts cmp.Option) (bool, error) {
+func Sync(deployContext *DeployContext, blueprint metav1.Object, diffOpts ...cmp.Option) (bool, error) {
 	// eclipse-che custom resource is being deleted, we shouldn't sync
 	// TODO move this check before `Sync` invocation
 	if !deployContext.CheCluster.ObjectMeta.DeletionTimestamp.IsZero() {
@@ -55,10 +55,13 @@ func Sync(deployContext *DeployContext, blueprint metav1.Object, diffOpts cmp.Op
 		return false, err
 	}
 
+	// set GroupVersionKind (it might be empty)
+	actual.GetObjectKind().SetGroupVersionKind(runtimeObject.GetObjectKind().GroupVersionKind())
 	if !exists {
 		return Create(deployContext, blueprint)
 	}
-	return Update(deployContext, actual, blueprint, diffOpts)
+
+	return Update(deployContext, actual, blueprint, diffOpts...)
 }
 
 func SyncAndAddFinalizer(
@@ -198,7 +201,7 @@ func DeleteClusterObject(deployContext *DeployContext, name string, objectMeta m
 
 // Updates object.
 // Returns true if object is up to date otherwiser return false
-func Update(deployContext *DeployContext, actual runtime.Object, blueprint metav1.Object, diffOpts cmp.Option) (bool, error) {
+func Update(deployContext *DeployContext, actual runtime.Object, blueprint metav1.Object, diffOpts ...cmp.Option) (bool, error) {
 	// eclipse-che custom resource is being deleted, we shouldn't sync
 	// TODO move this check before `Sync` invocation
 	if !deployContext.CheCluster.ObjectMeta.DeletionTimestamp.IsZero() {
@@ -210,10 +213,12 @@ func Update(deployContext *DeployContext, actual runtime.Object, blueprint metav
 		return false, fmt.Errorf("object %T is not a metav1.Object. Cannot sync it", actualMeta)
 	}
 
-	diff := cmp.Diff(actual, blueprint, diffOpts)
+	diff := cmp.Diff(actual, blueprint, diffOpts...)
 	if len(diff) > 0 {
-		logrus.Infof("Updating existing object: %s, name: %s", getObjectType(actualMeta), actualMeta.GetName())
-		fmt.Printf("Difference:\n%s", diff)
+		// don't print difference if there are no diffOpts mainly to avoid huge output
+		if len(diffOpts) != 0 {
+			fmt.Printf("Difference:\n%s", diff)
+		}
 
 		targetLabels := map[string]string{}
 		targetAnnos := map[string]string{}
@@ -237,6 +242,7 @@ func Update(deployContext *DeployContext, actual runtime.Object, blueprint metav
 
 		client := getClientForObject(actualMeta.GetNamespace(), deployContext)
 		if isUpdateUsingDeleteCreate(actual.GetObjectKind().GroupVersionKind().Kind) {
+			logrus.Infof("Recreating existing object: %s, name: %s", getObjectType(actualMeta), actualMeta.GetName())
 			done, err := doDelete(client, actual)
 			if !done {
 				return false, err
@@ -249,6 +255,7 @@ func Update(deployContext *DeployContext, actual runtime.Object, blueprint metav
 
 			return doCreate(client, blueprint.(runtime.Object), false)
 		} else {
+			logrus.Infof("Updating existing object: %s, name: %s", getObjectType(actualMeta), actualMeta.GetName())
 			err := setOwnerReferenceIfNeeded(deployContext, blueprint)
 			if err != nil {
 				return false, err
